//+------------------------------------------------------------------+
//|                                              Simple Breakout.mq4 |
//|                                          Copyright  2006, RoBiK |
//|                                                                  |
//+------------------------------------------------------------------+

/*
Originally Posted by highway3000
Simple Combined Breakout System for EUR/USD and GBP/USD

    * Determine the 06.00 CET  10.00 CET High Low on EUR/USD and GBP/USD
    * Determine the 10.00 CET  14.00 CET High Low on EUR/USD and GBP/USD
    * Set BuyStop at High + 5 pips and SellStop at Low - 5 pips for both timeframes and both currencies
    * Set Target Price at entry + 80 pips for EUR/USD and entry + 120 pips for GBP/USD
    * Set StopLoss at entry - 50 pips for EUR/USD and entry - 70 pips for GBP/USD. If the other side of the Breakout is within 50 pips for EUR/USD or within 70 pips for GBP/USD then the StopLoss will be that level (Longtrade: SL = Low range - 5 pips = SellStop; Shorttrade: SL = High range + 5 pips = BuyStop)
    * Use a trailing stop of 30 pips for EUR/USD and a trailing stop of 40 pips for GBP/USD
    * At 24.00 CET all orders expiring and close all trades at market. On Friday we do the same at 23.00 CET.

July +1352pips & October 2005 Profit +991 pips. Average per month so far +600pips/month

With help from James16 & Noos bar price action readings, you can add another addition 20% profit by exiting some winning trades before they becomes losing trades.
*/

#property copyright "Copyright  2006, RoBiK"
#property link      ""

extern int EntryDistance = 5;
extern int TP = 80;
extern int SL = 50;
extern int TrailingSL = 30;

datetime lastTime;
int openCount;
//+------------------------------------------------------------------+
//| expert initialization function                                   |
//+------------------------------------------------------------------+
int init()
  {
//----
  
//----
   return(0);
  }
//+------------------------------------------------------------------+
//| expert deinitialization function                                 |
//+------------------------------------------------------------------+
int deinit()
  {
//----
  lastTime = 0;
  openCount = 0; 
//----
   return(0);
  }
//+------------------------------------------------------------------+
//| expert start function                                            |
//+------------------------------------------------------------------+
int start()
  {
//----
  if (Time[0] != lastTime)
  {
    lastTime = Time[0];
    int h = Hour();
    if (h == 0 || (h == 22 && DayOfWeek() == 5))
    {
      Print("Closing");
      CloseOrders();
      openCount = 0;
    }
    if (h == 10 && openCount == 0)
    {
      OpenOrders(4);
      openCount++;      
    }
    if (h == 14 && openCount == 1)
    {
      OpenOrders(2);
      openCount++;
    }
  }
  TrailStopLoss();
//----
   return(0);
  }
//+------------------------------------------------------------------+
void CloseOrders()
{
  int total=OrdersTotal();
  for(int i = 0; i < total; i++)
  {
     OrderSelect(i, SELECT_BY_POS, MODE_TRADES);
     if(OrderSymbol()==Symbol())
     {
        switch (OrderType())
        {
          case OP_BUY:
            OrderClose(OrderTicket(), OrderLots(), Bid, 0, Violet);
            break;
          case OP_SELL:
            OrderClose(OrderTicket(), OrderLots(), Ask, 0, Violet);
            break;
          default:
            OrderDelete(OrderTicket());
            break;
        }
        i--;
        total--;
     }
  }   
}
//+------------------------------------------------------------------+
void OpenOrders(int hours)
{
  double hi = High[Highest(NULL, 0, MODE_HIGH, hours, 1)];
  double lo = Low[Lowest(NULL, 0, MODE_LOW, hours, 1)];
  OrderSend(Symbol(), OP_BUYSTOP, 1, hi + EntryDistance * Point, 0, MathMax(hi + (EntryDistance - SL) * Point, lo), hi + (EntryDistance + TP) * Point, "SIMPLE", 0, 0, Green);
  OrderSend(Symbol(), OP_SELLSTOP, 1, lo - EntryDistance * Point, 0, MathMin(lo - (EntryDistance - SL) * Point, hi), lo - (EntryDistance + TP) * Point, "SIMPLE", 0, 0, Red);
}
//+------------------------------------------------------------------+
void TrailStopLoss()
{
  int total=OrdersTotal();
  for(int i =0; i < total; i++)
  {
     OrderSelect(i, SELECT_BY_POS, MODE_TRADES);
     if(OrderSymbol()==Symbol())
     {
        double sl;
        if (OrderType() == OP_BUY)
        {
          sl = Bid - TrailingSL * Point;
          if (OrderStopLoss() < sl)
          {             
             OrderModify(OrderTicket(), OrderOpenPrice(), sl, OrderTakeProfit(), 0, Green);
          }
        }
        if (OrderType() == OP_SELL)
        {
          sl = Ask + TrailingSL * Point;
          if (OrderStopLoss() > sl)
          {             
             OrderModify(OrderTicket(), OrderOpenPrice(), sl, OrderTakeProfit(), 0, Red);
          }
        }
     }
  }
}
//+------------------------------------------------------------------+


